==> field_manager_python_client-4.4.82rc3.tar.gz: field_manager_python_client-4.4.82rc3/field-manager-python-client/api/piezometers/get_piezometer_model_projects_project_id_piezometers_models_model_id_get.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.http_validation_error import HTTPValidationError
from ...models.piezometer_model import PiezometerModel
from typing import cast
from typing import Dict
from uuid import UUID



def _get_kwargs(
    project_id: str,
    model_id: UUID,

) -> Dict[str, Any]:
    

    

    

    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": "/projects/{project_id}/piezometers/models/{model_id}".format(project_id=project_id,model_id=model_id,),
    }


    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    if response.status_code == 200:
        response_200 = PiezometerModel.from_dict(response.json())



        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())



        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,

) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    """ Get Piezometer Model

    Args:
        project_id (str):
        model_id (UUID):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PiezometerModel]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
model_id=model_id,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,

) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    """ Get Piezometer Model

    Args:
        project_id (str):
        model_id (UUID):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PiezometerModel]
     """


    return sync_detailed(
        project_id=project_id,
model_id=model_id,
client=client,

    ).parsed

async def asyncio_detailed(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,

) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    """ Get Piezometer Model

    Args:
        project_id (str):
        model_id (UUID):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PiezometerModel]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
model_id=model_id,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,

) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    """ Get Piezometer Model

    Args:
        project_id (str):
        model_id (UUID):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PiezometerModel]
     """


    return (await asyncio_detailed(
        project_id=project_id,
model_id=model_id,
client=client,

    )).parsed

==> field_manager_python_client-4.4.90rc6.tar.gz: field_manager_python_client-4.4.90rc6/field-manager-python-client/api/piezometers/get_piezometer_model_projects_project_id_piezometers_models_model_id_get.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.piezometer_model import PiezometerModel
from ...types import Response


def _get_kwargs(
    project_id: str,
    model_id: UUID,
) -> Dict[str, Any]:
    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": f"/projects/{project_id}/piezometers/models/{model_id}",
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    if response.status_code == 200:
        response_200 = PiezometerModel.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    """Get Piezometer Model

    Args:
        project_id (str):
        model_id (UUID):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PiezometerModel]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        model_id=model_id,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    """Get Piezometer Model

    Args:
        project_id (str):
        model_id (UUID):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PiezometerModel]
    """

    return sync_detailed(
        project_id=project_id,
        model_id=model_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
) -> Response[Union[HTTPValidationError, PiezometerModel]]:
    """Get Piezometer Model

    Args:
        project_id (str):
        model_id (UUID):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, PiezometerModel]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        model_id=model_id,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    model_id: UUID,
    *,
    client: AuthenticatedClient,
) -> Optional[Union[HTTPValidationError, PiezometerModel]]:
    """Get Piezometer Model

    Args:
        project_id (str):
        model_id (UUID):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, PiezometerModel]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            model_id=model_id,
            client=client,
        )
    ).parsed
